#!/bin/bash

# --------- config ---------
DEPLOYDIR=$PWD/DEPLOY
MAKEJOBS=8

prepare_GSL=YES
prepare_LAPACKwithBLAS=YES
prepare_ZLIB=YES
prepare_TIFF=YES
prepare_FFTW=YES


mkdir -p $DEPLOYDIR

echo ========================= GSL =========================
if [ "_$prepare_GSL" == "_YES" ]; then
	GSL_archive=gsl-2.6.tar.gz
	wget ftp://ftp.gnu.org/gnu/gsl/$GSL_archive
	tar -xzf $GSL_archive
	cd ${GSL_archive:0:7}
	./configure  --prefix=$DEPLOYDIR
	make -j${MAKEJOBS}
	make install
	cd ..
else
	echo "not now"
fi

echo ========================= LAPACK + BLAS =========================
if [ "_$prepare_LAPACKwithBLAS" == "_YES" ]; then
	LAPACK_archive=lapack-3.8.0.zip
	wget https://github.com/Reference-LAPACK/lapack-release/archive/$LAPACK_archive
	unzip $LAPACK_archive
	cd lapack-release-lapack-${LAPACK_archive:7:5}
	mkdir BUILD
	cd BUILD
	cmake -D CBLAS=ON -D LAPACKE=ON -D CMAKE_INSTALL_PREFIX=$DEPLOYDIR ..
	make -j${MAKEJOBS}
	make install
	cd ../..
else
	echo "not now"
fi

echo ========================= ZLIB =========================
if [ "_$prepare_ZLIB" == "_YES" ]; then
	ZLIB_archive=zlib-1.2.11.tar.gz
	wget https://www.zlib.net/$ZLIB_archive
	tar -xzf $ZLIB_archive
	cd ${ZLIB_archive:0:11}
	mkdir BUILD
	cd BUILD
	cmake -D CMAKE_INSTALL_PREFIX=$DEPLOYDIR ..
	make -j${MAKEJOBS}
	make install
	cd ../..
else
	echo "not now"
fi

echo ========================= TIFF =========================
if [ "_$prepare_TIFF" == "_YES" ]; then
	TIFF_archive=tiff-4.0.10.tar.gz
	wget http://download.osgeo.org/libtiff/$TIFF_archive
	tar -xzf $TIFF_archive
	cd ${TIFF_archive:0:11}
	mkdir BUILD
	cd BUILD
	cmake -D BUILD_SHARED_LIBS=OFF -D jbig=OFF -D jpeg=OFF -D jpeg12=OFF -D webp=OFF -D zstd=OFF -D CMAKE_INSTALL_PREFIX=$DEPLOYDIR ..
	make -j${MAKEJOBS}
	make install
	cd ../..
else
	echo "not now"
fi

echo ========================= FFTW =========================
if [ "_$prepare_FFTW" == "_YES" ]; then
	FFTW_archive=fftw-3.3.8.tar.gz
	wget http://www.fftw.org/$FFTW_archive
	tar -xzf $FFTW_archive
	cd ${TIFF_archive:0:10}
	mkdir BUILD
	cd BUILD
	cmake -D BUILD_SHARED_LIBS=OFF -D DISABLE_FORTRAN=ON -D ENABLE_FLOAT=ON  -D ENABLE_LONG_DOUBLE=OFF -D ENABLE_THREADS=ON -D CMAKE_INSTALL_PREFIX=$DEPLOYDIR ..
	make -j${MAKEJOBS} install
	cmake -D BUILD_SHARED_LIBS=OFF -D DISABLE_FORTRAN=ON -D ENABLE_FLOAT=OFF -D ENABLE_LONG_DOUBLE=OFF -D ENABLE_THREADS=ON -D CMAKE_INSTALL_PREFIX=$DEPLOYDIR ..
	make -j${MAKEJOBS} install
	cmake -D BUILD_SHARED_LIBS=OFF -D DISABLE_FORTRAN=ON -D ENABLE_FLOAT=OFF -D ENABLE_LONG_DOUBLE=ON  -D ENABLE_THREADS=ON -D CMAKE_INSTALL_PREFIX=$DEPLOYDIR ..
	make -j${MAKEJOBS} install
	cd ../..
else
	echo "not now"
fi
